@@ -10,11 +10,7 @@ rowShuffle <- function(x) {
 
 #[export]
 colShuffle <- function(x) {
-	dm <- dim(x)
-	ind <- .Call(Rfast_col_shuffle,dm[1],dm[2])
-	x <- x[ind]
-	dim(x) <- dm
-	x
+	.Call(Rfast_col_shuffle,x)
 }
 
 #[export]
